@@ -5,7 +5,7 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2022 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 #ifndef __XMLSEC_APP_H__
 #define __XMLSEC_APP_H__
@@ -85,7 +85,7 @@ XMLSEC_EXPORT xmlSecKeyDataId                   xmlSecKeyDataDsaGetKlass(void);
  *
  * The EC key klass.
  */
-#define xmlSecKeyDataEcId                       xmlSecKeyDataEcetKlass()
+#define xmlSecKeyDataEcId                       xmlSecKeyDataEcGetKlass()
 XMLSEC_EXPORT xmlSecKeyDataId                   xmlSecKeyDataEcGetKlass(void);
 /**
  * xmlSecKeyDataGost2001Id:
