@@ -1,24 +1,25 @@
-/**
+/*
  * XML Security Library (http://www.aleksey.com/xmlsec).
  *
- * All the string constans.
+ * All the string constants.
  *
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2003 Aleksey Sanin <aleksey@aleksey.com>
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 #ifndef __XMLSEC_STRINGS_H__
 #define __XMLSEC_STRINGS_H__
 
+#include <libxml/tree.h>
+
+#include <xmlsec/exports.h>
+#include <xmlsec/xmlsec.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
-#include <libxml/tree.h>
-
-#include <xmlsec/xmlsec.h>
-
 /*************************************************************************
  *
  * Global Namespaces
@@ -26,13 +27,12 @@ extern "C" {
  ************************************************************************/
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNs[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecDSigNs[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecDSig11Ns[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecEncNs[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsNs[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecEnc11Ns[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecXPathNs[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecXPath2Ns[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecXPointerNs[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecSoap11Ns[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecSoap12Ns[];
 
 
 /*************************************************************************
@@ -71,127 +71,6 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeCarriedKeyName[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecTypeEncContent[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecTypeEncElement[];
 
-/*************************************************************************
- *
- * XKMS nodes, attributes  and value strings
- *
- ************************************************************************/
-#ifndef XMLSEC_NO_XKMS
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestResultName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestStatusName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestLocateName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestValidateName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestCompoundName[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeResult[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeStatusRequest[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeStatusResult[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeLocateRequest[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeLocateResult[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidateRequest[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidateResult[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeCompoundRequest[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeCompoundResult[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeMessageExtension[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeOpaqueClientData[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeResponseMechanism[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRespondWith[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodePendingNotification[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeQueryKeyBinding[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeKeyUsage[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeUseKeyWith[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeTimeInstant[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRequestSignatureValue[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeUnverifiedKeyBinding[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidityInterval[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeStatus[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidReason[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeInvalidReason[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeIndeterminateReason[];
-
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrService[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrNonce[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrOriginalRequestId[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrResponseLimit[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrMechanism[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrIdentifier[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrApplication[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrResultMajor[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrResultMinor[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrRequestId[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrNotBefore[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrNotOnOrAfter[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrTime[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrStatusValue[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseMechanismPending[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseMechanismRepresent[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseMechanismRequestSignatureValue[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithKeyName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithKeyValue[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithX509Cert[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithX509Chain[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithX509CRL[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithOCSP[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithRetrievalMethod[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithPGP[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithPGPWeb[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithSPKI[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithPrivateKey[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecStatusResultSuccess[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecStatusResultFailed[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecStatusResultPending[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyUsageEncryption[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyUsageSignature[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyUsageExchange[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingStatusValid[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingStatusInvalid[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingStatusIndeterminate[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonIssuerTrust[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonRevocationStatus[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonValidityInterval[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonSignature[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeSuccess[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeVersionMismatch[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeSender[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeReceiver[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeRepresent[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodePending[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeNoMatch[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeTooManyResponses[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeIncomplete[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeFailure[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeRefused[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeNoAuthentication[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeMessageNotSupported[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeUnknownResponseId[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeNotSynchronous[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonLang[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonUnsupportedVersion[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonUnableToProcess[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonServiceUnavailable[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonMessageNotSupported[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonMessageInvalid[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapSubcodeValueMessageNotSupported[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapSubcodeValueBadMessage[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsFormatStrPlain[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsFormatStrSoap11[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsFormatStrSoap12[];
-
-#endif /* XMLSEC_NO_XKMS */
-
 /*************************************************************************
  *
  * KeyInfo and Transform Nodes
@@ -235,6 +114,15 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes192Cbc[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameAes256Cbc[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes256Cbc[];
 
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameAes128Gcm[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes128Gcm[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameAes192Gcm[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes192Gcm[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameAes256Gcm[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes256Gcm[];
+
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameKWAes128[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefKWAes128[];
 
@@ -281,6 +169,33 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNsExcC14NWithComments[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeInclusiveNamespaces[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrPrefixList[];
 
+/*************************************************************************
+ *
+ * ConcatKDF strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameConcatKdfKeyValue[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameConcatKdf[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefConcatKdf[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeConcatKDFParams[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeConcatKDFAttrAlgorithmID[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeConcatKDFAttrPartyUInfo[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeConcatKDFAttrPartyVInfo[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeConcatKDFAttrSuppPubInfo[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeConcatKDFAttrSuppPrivInfo[];
+
+
+/*************************************************************************
+ *
+ * DEREncodedKeyValue strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameDEREncodedKeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDEREncodedKeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDEREncodedKeyValue[];
+
 /*************************************************************************
  *
  * DES strings
@@ -296,6 +211,30 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDes3Cbc[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameKWDes3[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefKWDes3[];
 
+/*************************************************************************
+ *
+ * DH key strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameDHKeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDHKeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDHKeyValue[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDHP[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDHQ[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDHGenerator[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDHPublic[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDHSeed[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDHPgenCounter[];
+
+/*************************************************************************
+ *
+ * DH-ES key agreement strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameDhEs[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDhEs[];
+
 /*************************************************************************
  *
  * DSA strings
@@ -318,6 +257,65 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDSAPgenCounter[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameDsaSha1[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDsaSha1[];
 
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameDsaSha256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDsaSha256[];
+
+/*************************************************************************
+ *
+ * EC key strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameECKeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECKeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefECKeyValue[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeNamedCurve[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodePublicKey[];
+
+
+/*************************************************************************
+ *
+ * ECDH key agreement strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdh[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdh[];
+
+/*************************************************************************
+ *
+ * ECDSA sigantures strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaRipemd160[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaRipemd160[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha1[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha1[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha224[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha384[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha512[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha3_224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha3_224[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha3_256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha3_256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha3_384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha3_384[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha3_512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha3_512[];
+
 /*************************************************************************
  *
  * GOST2001 strings
@@ -330,6 +328,25 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGOST2001KeyValue[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGost2001GostR3411_94[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGost2001GostR3411_94[];
 
+/*************************************************************************
+ *
+ * GOST R 34.10-2012 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3410_2012_256KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeGostR3410_2012_256KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3410_2012_256KeyValue[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3410_2012_512KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeGostR3410_2012_512KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3410_2012_512KeyValue[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3410_2012GostR3411_2012_256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3410_2012GostR3411_2012_256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3410_2012GostR3411_2012_512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3410_2012GostR3411_2012_512[];
+
 /*************************************************************************
  *
  * EncryptedKey
@@ -339,6 +356,33 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEncryptedKey[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeEncryptedKey[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEncryptedKey[];
 
+/*************************************************************************
+ *
+ * DerivedKey
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameDerivedKey[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDerivedKey[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDerivedKey[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeKeyDerivationMethod[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDerivedKeyName[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeMasterKeyName[];
+
+/*************************************************************************
+ *
+ * AgreementMethod
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameAgreementMethod[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeAgreementMethod[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAgreementMethod[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeOriginatorKeyInfo[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRecipientKeyInfo[];
+
+
+
 /*************************************************************************
  *
  * Enveloped transform strings
@@ -379,6 +423,15 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacSha384[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacSha512[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacSha512[];
 
+
+/*************************************************************************
+ *
+ * KeyInfoReference
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameKeyInfoReference[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeKeyInfoReference[];
+
 /*************************************************************************
  *
  * KeyName strings
@@ -410,6 +463,24 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNameMemBuf[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameMd5[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefMd5[];
 
+/*************************************************************************
+ *
+ * PBKDF2 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNamePbkdf2KeyValue[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNamePbkdf2[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefPbkdf2[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodePbkdf2Params[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodePbkdf2Salt[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodePbkdf2SaltSpecified[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodePbkdf2IterationCount[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodePbkdf2KeyLength[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodePbkdf2PRF[];
+
+
 /*************************************************************************
  *
  * RetrievalMethod
@@ -465,7 +536,49 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPkcs1[];
 
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaOaep[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaOaep[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaOaepEnc11[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaOaepEnc11[];
+
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRsaOAEPparams[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRsaMGF[];
+
+/* MGF1 urls (https://www.w3.org/TR/xmlenc-core1/#sec-RSA-OAEP) */
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefMgf1Sha1[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefMgf1Sha224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefMgf1Sha256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefMgf1Sha384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefMgf1Sha512[];
+
+
+/* RSS PSS https://www.rfc-editor.org/rfc/rfc9231.txt */
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPssSha1[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPssSha1[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPssSha224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPssSha224[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPssSha256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPssSha256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPssSha384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPssSha384[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPssSha512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPssSha512[];
+
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPssSha3_224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPssSha3_224[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPssSha3_256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPssSha3_256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPssSha3_384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPssSha3_384[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPssSha3_512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPssSha3_512[];
 
 /*************************************************************************
  *
@@ -475,6 +588,16 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRsaOAEPparams[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3411_94[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3411_94[];
 
+/*************************************************************************
+ *
+ * GOST R 34.11-2012 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3411_2012_256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3411_2012_256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3411_2012_512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3411_2012_512[];
+
 /*************************************************************************
  *
  * SHA1 strings
@@ -483,6 +606,11 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3411_94[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha1[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha1[];
 
+/*************************************************************************
+ *
+ * SHA2 strings
+ *
+ ************************************************************************/
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha224[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha224[];
 
@@ -495,6 +623,24 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha384[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha512[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha512[];
 
+/*************************************************************************
+ *
+ * SHA3 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha3_224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha3_224[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha3_256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha3_256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha3_384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha3_384[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha3_512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha3_512[];
+
+
 /*************************************************************************
  *
  * X509 strings
@@ -511,6 +657,7 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeX509IssuerSerial[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeX509IssuerName[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeX509SerialNumber[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeX509SKI[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeX509Digest[];
 
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRawX509Cert[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRawX509Cert[];
@@ -551,6 +698,22 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecXPath2FilterUnion[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameXPointer[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeXPointer[];
 
+/*************************************************************************
+ *
+ * RelationshipTransform strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRelationship[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRelationship[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRelationship[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRelationshipReference[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipsNs[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipReferenceNs[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipAttrId[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipAttrSourceId[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipAttrTargetMode[];
+
 /*************************************************************************
  *
  * Xslt strings
@@ -559,40 +722,6 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeXPointer[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameXslt[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefXslt[];
 
-#ifndef XMLSEC_NO_SOAP
-/*************************************************************************
- *
- * SOAP 1.1/1.2 strings
- *
- ************************************************************************/
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeEnvelope[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeHeader[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeBody[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFault[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFaultCode[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFaultString[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFaultActor[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFaultDetail[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeCode[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeReason[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeNode[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRole[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDetail[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValue[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeSubcode[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeText[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeVersionMismatch[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeMustUnderstand[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeClient[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeServer[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeReceiver[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeSender[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultDataEncodningUnknown[];
-
-
-#endif /* XMLSEC_NO_SOAP */
-
 /*************************************************************************
  *
  * Utility strings
@@ -606,5 +735,3 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecStringCR[];
 #endif /* __cplusplus */
 
 #endif /* __XMLSEC_STRINGS_H__ */
-
-
